@@ -24,7 +24,7 @@ class Api(object):
             >>> import paypalrestsdk
             >>> api = paypalrestsdk.Api(mode="sandbox", server_key='SERVER_KEY')
         """
-        kwargs = util.merge_dict(options or {}, kwargs)
+        kwargs = merge_dict(options or {}, kwargs)
 
         self.mode = kwargs.get("mode", "sandbox")
 
@@ -146,7 +146,7 @@ class Api(object):
             >>> api.get("v1/payments/payment?count=1")
             >>> api.get("v1/payments/payment/PAY-1234")
         """
-        return self.request(util.join_url(self.endpoint, action), 'GET')
+        return self.request(join_url(self.endpoint, action), 'GET')
 
     def post(self, action, params=None):
         """Make POST request
@@ -157,7 +157,7 @@ class Api(object):
             >>> api.post("v1/payments/payment/PAY-1234/execute", { 'payer_id': '1234' })
 
         """
-        return self.request(util.join_url(self.endpoint, action), 'POST', body=params or {})
+        return self.request(join_url(self.endpoint, action), 'POST', body=params or {})
 
     def put(self, action, params=None):
         """Make PUT request
@@ -166,7 +166,7 @@ class Api(object):
 
             >>> api.put("v1/invoicing/invoices/INV2-RUVR-ADWQ", { 'id': 'INV2-RUVR-ADWQ', 'status': 'DRAFT'})
         """
-        return self.request(util.join_url(self.endpoint, action), 'PUT', body=params or {})
+        return self.request(join_url(self.endpoint, action), 'PUT', body=params or {})
 
     def patch(self, action, params=None):
         """Make PATCH request
@@ -175,12 +175,12 @@ class Api(object):
 
             >>> api.patch("v1/payments/billing-plans/P-5VH69258TN786403SVUHBM6A", { 'op': 'replace', 'path': '/merchant-preferences'})
         """
-        return self.request(util.join_url(self.endpoint, action), 'PATCH', body=params or {})
+        return self.request(join_url(self.endpoint, action), 'PATCH', body=params or {})
 
     def delete(self, action):
         """Make DELETE request
         """
-        return self.request(util.join_url(self.endpoint, action), 'DELETE')
+        return self.request(join_url(self.endpoint, action), 'DELETE')
 
 __api__ = None
 
